@@ -7,8 +7,7 @@ Authors
 """
 
 import logging
-import numpy as np   
-from collections import OrderedDict
+import numpy as np
 
 from xicsrt.util import profiler
 from xicsrt.tools.xicsrt_doc import dochelper
@@ -22,7 +21,9 @@ class XicsrtPlasmaCubic(XicsrtPlasmaGeneric):
     """
                 
     def bundle_generate(self, bundle_input):
-        
+
+        bundle_input = super().bundle_generate(bundle_input)
+
         #evaluate temperature at each point
         #plasma cube has consistent temperature throughout
         bundle_input['temperature'][:] = self.param['temperature']
