@@ -11,9 +11,10 @@ from scipy.stats import cauchy
 import scipy.constants as const
 
 from xicsrt.util import profiler
-from xicsrt.tools import voigt
-from xicsrt.tools import xicsrt_dist
+from xicsrt.tools import xicsrt_voigt
+from xicsrt.tools import xicsrt_spread
 from xicsrt.tools.xicsrt_doc import dochelper
+from xicsrt.objects._RayArray import RayArray
 from xicsrt.objects._GeometryObject import GeometryObject
 
 @dochelper
@@ -175,7 +176,7 @@ class XicsrtSourceGeneric(GeometryObject):
         self.param['intensity'] = int(self.param['intensity'])
         
     def generate_rays(self):
-        rays = dict()
+        rays = RayArray()
         profiler.start('generate_rays')
         
         profiler.start('generate_origin')
@@ -231,7 +232,7 @@ class XicsrtSourceGeneric(GeometryObject):
     def random_direction(self, normal):
 
         spread = self.param['spread']
-        dir_local  = xicsrt_dist.vector_distribution(
+        dir_local  = xicsrt_spread.vector_distribution(
             spread,
             self.param['intensity'],
             name=self.param['spread_dist'],
@@ -272,6 +273,8 @@ class XicsrtSourceGeneric(GeometryObject):
             #doppler shift
             c = const.physical_constants['speed of light in vacuum'][0]
             wavelength *= 1 - (np.einsum('j,ij->i', self.param['velocity'], direction) / c)
+        else:
+            raise Exception(f'Wavelength distribution {wtype} unknown')
         
         return wavelength
 
@@ -305,7 +308,7 @@ class XicsrtSourceGeneric(GeometryObject):
         sigma = (np.sqrt(self.param['temperature'] / self.param['mass_number'] / amu_kg / c**2 * ev_J)
                   * self.param['wavelength'] )
 
-        rand_wave  = voigt.voigt_random(gamma, sigma, size)
+        rand_wave  = xicsrt_voigt.voigt_random(gamma, sigma, size)
         rand_wave += self.param['wavelength']
         return rand_wave
 
